# load-templates [![NPM version](https://img.shields.io/npm/v/load-templates.svg?style=flat)](https://www.npmjs.com/package/load-templates) [![NPM downloads](https://img.shields.io/npm/dm/load-templates.svg?style=flat)](https://npmjs.org/package/load-templates) [![Build Status](https://img.shields.io/travis/jonschlinkert/load-templates.svg?style=flat)](https://travis-ci.org/jonschlinkert/load-templates)

Load templates/views using globs, file paths, objects, arrays, or key-value pairs.

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install load-templates --save
```

## Usage

In addition to what's shown in the below examples, if a glob pattern or valid filepath is passed, a `stat` object will be added to the `file` object as well.

```js
var loader = require('load-templates');
// optionally pass an object to use for caching the views
var cache = {};
var views = loader(cache);
```

**load views from objects**

```js
views({
  a: {path: 'a'},
  b: {path: 'b'},
  c: {path: 'c'}
});
```

**from key-value pairs**

```js
views('d', {path: 'd'});
views('e', {path: 'e'});
views('f', {path: 'f'});
```

**from globs or file paths**

```js
views(['views/*.js']); 
```

**Results**

All of the above examples combined result in:

```js
{
  a: {path: 'a'},
  b: {path: 'b'},
  c: {path: 'c'},
  d: {path: 'd'},
  e: {path: 'e'},
  f: {path: 'f'},
  g: {path: 'g'},
  h: {path: 'h'},
  i: {path: 'i'},
  j: {path: 'j'}
}
```

## Options

### options.cwd

Special (leading) characters are expanded on `options.cwd`

* `~` expands to user home. example: `{cwd: '~/foo'}`
* `@` expands to global npm modules. example: `{cwd: '@/bar'}`

### options.renameKey

Rename the key of each `file` object.

Type: `Function`

Default: `noop` Full filepath or whatever key is passed.

### glob options

All options are also passed to [matched](https://github.com/jonschlinkert/matched).

## Related projects

You might also be interested in these projects:

* [assemble](https://www.npmjs.com/package/assemble): Assemble is a powerful, extendable and easy to use static site generator for node.js. Used… [more](https://www.npmjs.com/package/assemble) | [homepage](https://github.com/assemble/assemble)
* [templates](https://www.npmjs.com/package/templates): System for creating and managing template collections, and rendering templates with any node.js template engine.… [more](https://www.npmjs.com/package/templates) | [homepage](https://github.com/jonschlinkert/templates)
* [verb](https://www.npmjs.com/package/verb): Documentation generator for GitHub projects. Verb is extremely powerful, easy to use, and is used… [more](https://www.npmjs.com/package/verb) | [homepage](https://github.com/verbose/verb)

## Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/jonschlinkert/load-templates/issues/new).

## Building docs

Generate readme and API documentation with [verb][]:

```sh
$ npm install verb && npm run docs
```

Or, if [verb][] is installed globally:

```sh
$ verb
```

## Running tests

Install dev dependencies:

```sh
$ npm install -d && npm test
```

## Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

## License

Copyright © 2016, [Jon Schlinkert](https://github.com/jonschlinkert).
Released under the [MIT license](https://github.com/jonschlinkert/load-templates/blob/master/LICENSE).

***

_This file was generated by [verb](https://github.com/verbose/verb), v0.9.0, on May 07, 2016._